==> pseudomatic-0.1.1.tar.gz: pseudomatic-0.1.1/pseudomatic/names.py <==
# English lists
EN_ADJECTIVES = { 'M': [
    "Anonymous", "Curious", "Brave", "Clever", "Gentle", "Mighty", "Quiet", "Swift", "Witty", "Zany",
    "Fearless", "Joyful", "Restless", "Timeless", "Boundless", "Careful", "Hopeful", "Thoughtful", "Playful", "Cheerful"
]}

EN_NOUNS = [
    "Panda", "Mole", "Fox", "Eagle", "Tiger", "Otter", "Hawk", "Bear", "Wolf", "Dolphin",
    "Falcon", "Lion", "Cheetah", "Penguin", "Shark", "Rabbit", "Turtle", "Dragon", "Phoenix", "Leopard",
    "Beaver", "Cat", "Elephant", "Monkey", "Hare", "Moose", "She-wolf", "Boar", "Owl", "Vixen",
    "Hedgehog", "Badger", "Antelope", "Buffalo", "Gazelle", "Giraffe", "Hippo", "Jaguar", "Koala", "Lynx",
]

EN_GENDER = ['M'] * len(EN_NOUNS)

# Ukrainian lists
UA_ADJECTIVES_M = [
]
UA_ADJECTIVES = {
    'M': [
        "Анонімний", "Допитливий", "Хоробрий", "Кмітливий", "Ніжний", "Могутній", "Тихий", "Швидкий", "Дотепний",
        "Дивний", "Безстрашний", "Радісний", "Неспокійний", "Позачасовий", "Безмежний", "Дбайливий", "Сповнений надії",
        "Думливий", "Грайливий", "Веселий"
    ],
    'F':  [
        "Анонімна", "Допитлива", "Хоробра", "Кмітлива", "Ніжна", "Могутня", "Тиха", "Швидка", "Дотепна", "Дивна",
        "Безстрашна", "Радісна", "Неспокійна", "Позачасова", "Безмежна", "Дбайлива", "Сповнена надії", "Думлива",
        "Грайлива", "Весела"
    ]
}
UA_NOUNS = [
    "Панда", "Кріт", "Лис", "Орел", "Тигр", "Видра", "Яструб", "Ведмідь", "Вовк", "Дельфін",
    "Сокіл", "Лев", "Гепард", "Пінгвін", "Акула", "Кролик", "Черепаха", "Дракон", "Фенікс", "Леопард",
    "Бобер", "Кіт", "Слон", "Мавпа", "Заяц", "Лось", "Вовчиця", "Кабан", "Сова", "Лисиця",
    "Їжак", "Барсук", "Антилопа", "Бик", "Газель", "Жираф", "Бегемот", "Ягуар", "Кенгуру", "Рись",
]

UA_GENDER = [
    "F", "M", "M", "M", "M", "F", "M", "M", "M", "M", "M", "M", "M", "M", "F", "M", "F", "M", "M", "M",
    "M", "M", "M", "F", "M", "M", "F", "M", "F", "F", "M", "M", "F", "M", "F", "M", "M", "M", "M", "F",
]


# Business lists
EN_ADJECTIVES_BUSINESS = {'M': [
    "Ambitious", "Agile", "Bold", "Corporate", "Disruptive", "Dynamic", "Efficient", "Ethical", "Focused",
    "Global", "Innovative", "Lean", "Loyal", "Modern", "Passionate", "Predictive", "Reliable", "Scalable",
    "Strategic", "Sustainable", "Trusted", "Visionary", "Winning", "Productive", "Resilient"
]}

EN_NOUNS_BUSINESS = [
    "Advisor", "Analyst", "Board", "Brand", "Capital", "CEO", "Consultant", "Deal", "Director", "Enterprise",
    "Executive", "Expert", "Firm", "Founder", "Growth", "Leader", "Manager", "Market", "Partner", "Startup",
    "Strategist", "Team", "Venture", "Vision"
]

EN_GENDER_BUSINESS = ['M'] * len(EN_NOUNS_BUSINESS)

UA_ADJECTIVES_BUSINESS = {
    'M': [
        "Амбітний", "Гнучкий", "Сміливий", "Корпоративний", "Революційний", "Динамічний", "Ефективний", "Етичний",
        "Сфокусований", "Глобальний", "Інноваційний", "Стрункий", "Вірний", "Сучасний", "Пристрасний",
        "Прогнозуючий", "Надійний", "Масштабований", "Стратегічний", "Сталий", "Довірений", "Візіонерський",
        "Переможний", "Продуктивний", "Стійкий"
    ],
    'F': [
        "Амбітна", "Гнучка", "Смілива", "Корпоративна", "Революційна", "Динамічна", "Ефективна", "Етична",
        "Сфокусована", "Глобальна", "Інноваційна", "Струнка", "Вірна", "Сучасна", "Пристрастна",
        "Прогнозуюча", "Надійна", "Масштабована", "Стратегічна", "Стійка", "Довірена", "Візіонерська",
        "Переможна", "Продуктивна", "Стійка"
    ],
    'N': [
        "Амбітне", "Гнучке", "Сміливе", "Корпоративне", "Революційне", "Динамічне", "Ефективне", "Етичне",
        "Сфокусоване", "Глобальне", "Інноваційне", "Струнке", "Вірне", "Сучасне", "Пристрастне",
        "Прогнозуюче", "Надійне", "Масштабоване", "Стратегічне", "Стійке", "Довірене", "Візіонерське",
        "Переможне", "Продуктивне", "Стійке"
    ]
}

UA_NOUNS_BUSINESS = [
    "Консультант", "Аналізатор", "Правління", "Бренд", "Капітал", "Генеральний директор", "Консультант",
    "Угода", "Директор", "Підприємство", "Виконавчий директор", "Експерт", "Фірма", "Засновник", "Зростання",
    "Лідер", "Менеджер", "Ринок", "Партнер", "Стартап", "Стратег", "Команда", "Венчурний капітал",
    "Візіонер"
]

UA_GENDER_BUSINESS = [
    "M", "M", "N", "M", "M", "M", "M",
    "Угода", "M", "M", "M", "M", "F", "M", "N",
    "M", "M", "M", "M", "M", "M", "F", "M",
    "M"
]

# Market lists
EN_ADJECTIVES_MARKET = {'M': [
    "Affordable", "Attractive", "Bargain", "Branded", "Convenient", "Discounted", "Exclusive", "Fresh", "Handcrafted",
    "Limited", "Luxury", "Organic", "Popular", "Premium", "Promotional", "Quality", "Seasonal", "Trendy", "Unique",
    "Valuable", "Vintage", "Wholesale", "Retail", "Fashionable", "Bestselling"
]}

EN_NOUNS_MARKET = [
    "Boutique", "Buyer", "Cashier", "Consumer", "Customer", "Discount", "Display", "Mall", "Marketplace", "Merchant",
    "Outlet", "Product", "Promotion", "Purchase", "Retailer", "Sale", "Seller", "Shelf", "Shop", "Shopper",
    "Store", "Supermarket", "Vendor", "Warehouse", "Brand"
]

EN_GENDER_MARKET = ['M'] * len(EN_NOUNS_MARKET)

UA_ADJECTIVES_MARKET = {
    'M': [
        "Доступний", "Привабливий", "Вигідний", "Брендовий", "Зручний", "Знижений", "Ексклюзивний", "Свіжий", "Рукотворний",
        "Обмежений", "Розкішний", "Органічний", "Популярний", "Преміальний", "Акційний", "Якісний", "Сезонний", "Модний", "Унікальний",
        "Цінний", "Вінтажний", "Оптовий", "Роздрібний", "Стильний", "Бестселерний"
    ],
    'F': [
        "Доступна", "Приваблива", "Вигідна", "Брендова", "Зручна", "Знижена", "Ексклюзивна", "Свіжа", "Рукотворна",
        "Обмежена", "Розкішна", "Органічна", "Популярна", "Преміальна", "Акційна", "Якісна", "Сезонна", "Модна", "Унікальна",
        "Цінна", "Вінтажна", "Оптова", "Роздрібна", "Стильна", "Бестселерна"
    ],
    'N': [
        "Доступне", "Привабливе", "Вигідне", "Брендове", "Зручне", "Знижене", "Ексклюзивне", "Свіже", "Рукотворне",
        "Обмежене", "Розкішне", "Органічне", "Популярне", "Преміальне", "Акційне", "Якісне", "Сезонне", "Модне", "Унікальне",
        "Цінне", "Вінтажне", "Оптове", "Роздрібне", "Стильне", "Бестселерне"
    ]
}

UA_NOUNS_MARKET = [
    "Бутік", "Покупець", "Касир", "Споживач", "Клієнт", "Знижка", "Вітрина", "Торговий центр", "Ринок", "Торговець",
    "Аутлет", "Товар", "Акція", "Покупка", "Роздрібник", "Розпродаж", "Продавець", "Полиця", "Магазин", "Шопер",
    "Крамниця", "Супермаркет", "Постачальник", "Склад", "Бренд"
]

UA_GENDER_MARKET = [
    "M", "M", "M", "M", "M", "F", "F", "M", "M", "M",
    "M", "M", "F", "F", "M", "M", "M", "F", "M", "M",
    "F", "M", "M", "M", "M"
]

==> pseudomatic-0.1.2.tar.gz: pseudomatic-0.1.2/pseudomatic/names.py <==
# English lists
EN_ADJECTIVES = {'M': [
    "Anonymous", "Curious", "Brave", "Clever", "Gentle", "Mighty", "Quiet", "Swift", "Witty", "Zany",
    "Fearless", "Joyful", "Restless", "Timeless", "Boundless", "Careful", "Hopeful", "Thoughtful", "Playful", "Cheerful"
]}

EN_NOUNS = [
    "Panda", "Mole", "Fox", "Eagle", "Tiger", "Otter", "Hawk", "Bear", "Wolf", "Dolphin",
    "Falcon", "Lion", "Cheetah", "Penguin", "Shark", "Rabbit", "Turtle", "Dragon", "Phoenix", "Leopard",
    "Beaver", "Cat", "Elephant", "Monkey", "Hare", "Moose", "She-wolf", "Boar", "Owl", "Vixen",
    "Hedgehog", "Badger", "Antelope", "Buffalo", "Gazelle", "Giraffe", "Hippo", "Jaguar", "Koala", "Lynx",
]

EN_GENDER = ['M'] * len(EN_NOUNS)

# Ukrainian lists
UA_ADJECTIVES_M = [
]
UA_ADJECTIVES = {
    'M': [
        "Анонімний", "Допитливий", "Хоробрий", "Кмітливий", "Ніжний", "Могутній", "Тихий", "Швидкий", "Дотепний",
        "Дивний", "Безстрашний", "Радісний", "Неспокійний", "Позачасовий", "Безмежний", "Дбайливий", "Сповнений надії",
        "Думливий", "Грайливий", "Веселий"
    ],
    'F': [
        "Анонімна", "Допитлива", "Хоробра", "Кмітлива", "Ніжна", "Могутня", "Тиха", "Швидка", "Дотепна", "Дивна",
        "Безстрашна", "Радісна", "Неспокійна", "Позачасова", "Безмежна", "Дбайлива", "Сповнена надії", "Думлива",
        "Грайлива", "Весела"
    ]
}
UA_NOUNS = [
    "Панда", "Кріт", "Лис", "Орел", "Тигр", "Видра", "Яструб", "Ведмідь", "Вовк", "Дельфін",
    "Сокіл", "Лев", "Гепард", "Пінгвін", "Акула", "Кролик", "Черепаха", "Дракон", "Фенікс", "Леопард",
    "Бобер", "Кіт", "Слон", "Мавпа", "Заяц", "Лось", "Вовчиця", "Кабан", "Сова", "Лисиця",
    "Їжак", "Барсук", "Антилопа", "Бик", "Газель", "Жираф", "Бегемот", "Ягуар", "Кенгуру", "Рись",
]

UA_GENDER = [
    "F", "M", "M", "M", "M", "F", "M", "M", "M", "M", "M", "M", "M", "M", "F", "M", "F", "M", "M", "M",
    "M", "M", "M", "F", "M", "M", "F", "M", "F", "F", "M", "M", "F", "M", "F", "M", "M", "M", "M", "F",
]

# Business lists
EN_ADJECTIVES_BUSINESS = {'M': [
    "Ambitious", "Agile", "Bold", "Corporate", "Disruptive", "Dynamic", "Efficient", "Ethical", "Focused",
    "Global", "Innovative", "Lean", "Loyal", "Modern", "Passionate", "Predictive", "Reliable", "Scalable",
    "Strategic", "Sustainable", "Trusted", "Visionary", "Winning", "Productive", "Resilient"
]}

EN_NOUNS_BUSINESS = [
    "Advisor", "Analyst", "Board", "Brand", "Capital", "CEO", "Consultant", "Deal", "Director", "Enterprise",
    "Executive", "Expert", "Firm", "Founder", "Growth", "Leader", "Manager", "Market", "Partner", "Startup",
    "Strategist", "Team", "Venture", "Vision"
]

EN_GENDER_BUSINESS = ['M'] * len(EN_NOUNS_BUSINESS)

UA_ADJECTIVES_BUSINESS = {
    'M': [
        "Амбітний", "Гнучкий", "Сміливий", "Корпоративний", "Революційний", "Динамічний", "Ефективний", "Етичний",
        "Сфокусований", "Глобальний", "Інноваційний", "Стрункий", "Вірний", "Сучасний", "Пристрасний",
        "Прогнозуючий", "Надійний", "Масштабований", "Стратегічний", "Сталий", "Довірений", "Візіонерський",
        "Переможний", "Продуктивний", "Стійкий"
    ],
    'F': [
        "Амбітна", "Гнучка", "Смілива", "Корпоративна", "Революційна", "Динамічна", "Ефективна", "Етична",
        "Сфокусована", "Глобальна", "Інноваційна", "Струнка", "Вірна", "Сучасна", "Пристрастна",
        "Прогнозуюча", "Надійна", "Масштабована", "Стратегічна", "Стійка", "Довірена", "Візіонерська",
        "Переможна", "Продуктивна", "Стійка"
    ],
    'N': [
        "Амбітне", "Гнучке", "Сміливе", "Корпоративне", "Революційне", "Динамічне", "Ефективне", "Етичне",
        "Сфокусоване", "Глобальне", "Інноваційне", "Струнке", "Вірне", "Сучасне", "Пристрастне",
        "Прогнозуюче", "Надійне", "Масштабоване", "Стратегічне", "Стійке", "Довірене", "Візіонерське",
        "Переможне", "Продуктивне", "Стійке"
    ]
}

UA_NOUNS_BUSINESS = [
    "Консультант", "Аналізатор", "Правління", "Бренд", "Капітал", "Генеральний директор", "Консультант",
    "Угода", "Директор", "Підприємство", "Виконавчий директор", "Експерт", "Фірма", "Засновник", "Зростання",
    "Лідер", "Менеджер", "Ринок", "Партнер", "Стартап", "Стратег", "Команда", "Венчурний капітал",
    "Візіонер"
]

UA_GENDER_BUSINESS = [
    "M", "M", "N", "M", "M", "M", "M",
    "Угода", "M", "M", "M", "M", "F", "M", "N",
    "M", "M", "M", "M", "M", "M", "F", "M",
    "M"
]

# Market lists
EN_ADJECTIVES_MARKET = {'M': [
    "Affordable", "Attractive", "Bargain", "Branded", "Convenient", "Discounted", "Exclusive", "Fresh", "Handcrafted",
    "Limited", "Luxury", "Organic", "Popular", "Premium", "Promotional", "Quality", "Seasonal", "Trendy", "Unique",
    "Valuable", "Vintage", "Wholesale", "Retail", "Fashionable", "Bestselling"
]}

EN_NOUNS_MARKET = [
    "Boutique", "Buyer", "Cashier", "Consumer", "Customer", "Discount", "Display", "Mall", "Marketplace", "Merchant",
    "Outlet", "Product", "Promotion", "Purchase", "Retailer", "Sale", "Seller", "Shelf", "Shop", "Shopper",
    "Store", "Supermarket", "Vendor", "Warehouse", "Brand"
]

EN_GENDER_MARKET = ['M'] * len(EN_NOUNS_MARKET)

UA_ADJECTIVES_MARKET = {
    'M': [
        "Доступний", "Привабливий", "Вигідний", "Брендовий", "Зручний", "Знижений", "Ексклюзивний", "Свіжий",
        "Рукотворний",
        "Обмежений", "Розкішний", "Органічний", "Популярний", "Преміальний", "Акційний", "Якісний", "Сезонний",
        "Модний", "Унікальний",
        "Цінний", "Вінтажний", "Оптовий", "Роздрібний", "Стильний", "Бестселерний"
    ],
    'F': [
        "Доступна", "Приваблива", "Вигідна", "Брендова", "Зручна", "Знижена", "Ексклюзивна", "Свіжа", "Рукотворна",
        "Обмежена", "Розкішна", "Органічна", "Популярна", "Преміальна", "Акційна", "Якісна", "Сезонна", "Модна",
        "Унікальна",
        "Цінна", "Вінтажна", "Оптова", "Роздрібна", "Стильна", "Бестселерна"
    ],
    'N': [
        "Доступне", "Привабливе", "Вигідне", "Брендове", "Зручне", "Знижене", "Ексклюзивне", "Свіже", "Рукотворне",
        "Обмежене", "Розкішне", "Органічне", "Популярне", "Преміальне", "Акційне", "Якісне", "Сезонне", "Модне",
        "Унікальне",
        "Цінне", "Вінтажне", "Оптове", "Роздрібне", "Стильне", "Бестселерне"
    ]
}

UA_NOUNS_MARKET = [
    "Бутік", "Покупець", "Касир", "Споживач", "Клієнт", "Знижка", "Вітрина", "Торговий центр", "Ринок", "Торговець",
    "Аутлет", "Товар", "Акція", "Покупка", "Роздрібник", "Розпродаж", "Продавець", "Полиця", "Магазин", "Шопер",
    "Крамниця", "Супермаркет", "Постачальник", "Склад", "Бренд"
]

UA_GENDER_MARKET = [
    "M", "M", "M", "M", "M", "F", "F", "M", "M", "M",
    "M", "M", "F", "F", "M", "M", "M", "F", "M", "M",
    "F", "M", "M", "M", "M"
]
